# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
from .x_master_password_handling2 import XMasterPasswordHandling2 as XMasterPasswordHandling2_59b91029
from .x_password_container import XPasswordContainer as XPasswordContainer_fe9d0e09
from .x_url_container import XUrlContainer as XUrlContainer_bbe40be9

class XPasswordContainer2(XMasterPasswordHandling2_59b91029, XPasswordContainer_fe9d0e09, XUrlContainer_bbe40be9):
    """
    Provides a unified interface for the PasswordContainer service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XPasswordContainer2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XPasswordContainer2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XPasswordContainer2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XPasswordContainer2'


__all__ = ['XPasswordContainer2']





# coding: utf-8
import uno
import typing
from ..dyn.frame.the_desktop import theDesktop
from ..dyn.reflection.the_core_reflection import theCoreReflection

if typing.TYPE_CHECKING:
    from ..lo.beans.property_value import PropertyValue
    from ..lo.beans.property_state import PropertyState
    from ..lo.frame.the_desktop import theDesktop
    from ..lo.lang.service_manager import ServiceManager
    # from ..lo.reflection.core_reflection import CoreReflection
    from ..lo.uno.x_component_context import XComponentContext
    from ..lo.uno.x_interface import XInterface
    from ..lo.lang.x_service_info import XServiceInfo

# region Cached Values
# The _STAR_DESKTOP object.  (global like in OOo Basic)
# It is cached in a global variable.
_STAR_DESKTOP: theDesktop = None
# The ServiceManager of the running OOo.
# It is cached in a global variable.
# _SERVICE_MGR: Optional[XMultiComponentFactory] = None
_SERVICE_MGR: 'ServiceManager' = None

# The CoreReflection object.
# It is cached in a global variable.
_CORE_REFLECTION: theCoreReflection = False
# endregion Cached Values

def get_service_manager() -> 'ServiceManager':
    """
    Get the ServiceManager from the running OpenOffice.org. 
    Then retain it in the global variable _SERVICE_MGR for future use. 
    This is similar to the GetProcessServiceManager() in OOo Basic. 
    
    Returns:
        XMultiComponentFactory: Service Manager
    """
    global _SERVICE_MGR
    if not _SERVICE_MGR:
        # Get the uno component context from the PyUNO runtime
        ctx: 'XComponentContext' = uno.getComponentContext()
        _SERVICE_MGR = ctx.getServiceManager()
    return _SERVICE_MGR


#------------------------------------------------------------
#   Uno convenience functions
#   The stuff in this section is just to make
#    python progrmaming of OOo more like using OOo Basic.
#------------------------------------------------------------

def create_uno_service(clazz: typing.Union[str, object], ctx: 'typing.Optional[XComponentContext]' = None, args: typing.Optional[typing.Tuple[object]] = None) -> 'XInterface':
    """A handy way to create a global objects within the running OOo. 
    Similar to the function of the same name in OOo Basic. 
    
    Args:
        clazz (str, object): name of the service or a service class to create an instance of.
        ctx (XComponentContext, optional): the context if required.
        args (Typle[object], optional): the arguments when needed.
    
    Returns:
        object: component instance

    Note:
        A service signals that it expects parameters during instantiation by supporting the com.sun.star.lang.XInitialization interface.
        There maybe services which can only be instantiated with parameters
    """
    is_class = False
    if isinstance(clazz, str):
        _cls = clazz
    elif hasattr(clazz, '__ooo_full_ns__'):
        _cls = clazz.__ooo_full_ns__
        is_class = True
    else:
        raise TypeError('create_uno_service() clazz incorrect type')
    srv = _create_uno_service(clazz=_cls, ctx=ctx,args=args)
    if is_class:
        srv.__dict__['__ooo_ns__'] = clazz.__ooo_ns__
        srv.__dict__['__ooo_full_ns__'] = clazz.__ooo_full_ns__
        srv.__dict__['__ooo_type_name__'] = clazz.__ooo_type_name__
    return srv

def _create_uno_service(clazz: str, ctx: 'typing.Optional[XComponentContext]' = None, args: typing.Optional[typing.Tuple[object]] = None) -> 'XInterface':
    """Creates a global objects within the running OOo. 
    Similar to the function of the same name in OOo Basic. 
    
    Args:
        clazz (str): name of the service to be instanciated.
        ctx (XComponentContext, optional): the context if required.
        args (List[object], optional): the arguments when needed.
    
    Returns:
        object: component instance

    Notes:
        A service signals that it expects parameters during instantiation by supporting the com.sun.star.lang.XInitialization interface.
        There maybe services which can only be instantiated with parameters
    """
    # https://wiki.openoffice.org/wiki/Documentation/DevGuide/ProUNO/Service_Manager
    # In case the service manager does not provide an implementation for a request,
    # a null reference is returned, so it is mandatory to check.
    # Every UNO exception may be thrown during instantiation.
    smgr = get_service_manager()
    if ctx and args:
        oObj = smgr.createInstanceWithArgumentsAndContext(clazz, args, ctx)
    elif args:
        oObj = smgr.createInstanceWithArguments(clazz, args)
    elif ctx:
        oObj = smgr.createInstanceWithContext(clazz, ctx)
    else:
        oObj = smgr.createInstance(clazz)
    return oObj


def get_desktop() -> theDesktop:
    """An easy way to obtain the Desktop object from a running OOo.
    
    Returns:
        object: com.sun.star.frame.Desktop
    
    See Also:
        `LibreOffice 7.2 SDK API theDesktop Reference <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1frame_1_1theDesktop.html>`_
    """
    global _STAR_DESKTOP
    if _STAR_DESKTOP == None:
        _STAR_DESKTOP = theDesktop()
    return _STAR_DESKTOP


# preload the _STAR_DESKTOP variable.
# get_desktop()


def get_core_reflection() -> theCoreReflection:
    '''
    This service is the implementation of the reflection API.
    
    Returns:
        object: com.sun.star.reflection.CoreReflection
    
    See Also:
        `LibreOffice 7.2 SDK theCoreReflection API Reference <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1reflection_1_1theCoreReflection.html>`_
    '''
    # https://stackoverflow.com/questions/67527942/why-cant-an-annotated-variable-be-global
    global _CORE_REFLECTION
    if not _CORE_REFLECTION:
        _CORE_REFLECTION = theCoreReflection()
    return _CORE_REFLECTION


def create_uno_struct(type_name: str) -> object:
    """Create a UNO struct and return it. 
    Similar to the function of the same name in OOo Basic. 
    
    Returns:
        object: uno struct
    """
    core_reflection = get_core_reflection()
    # Get the IDL class for the type name
    x_idl_class = core_reflection.forName(type_name)
    # Create the struct.
    _, struct = x_idl_class.createObject(None)
    return struct



#------------------------------------------------------------
#   High level general purpose functions
#------------------------------------------------------------


def make_property_value(name: typing.Optional[str] = None, value: object = None, handle: typing.Optional[int] = None, state: 'typing.Optional[PropertyState]' = None) -> 'PropertyValue':
    """
    Create a com.sun.star.beans.PropertyValue.
    
    Args:
        name (:obj:`str`, optional): Specifies the name of the property.
        value (:obj:`any`, optional): Contains the value of the property or ``None``, if no value is available.
        handle (:obj:`int`, optional): Contains an implementation-specific handle for the property.
        state (:obj:`com::sun::star::beans::PropertyState`, optional): Determines if the value comes from the object itself or from a default and if the value cannot be determined exactly.
    
    Returns:
        PropertyValue: ``com.sun.star.beans.PropertyValue`` struct.
    
    See Also:
        `LibreOffice API - PropertyValue Struct Reference <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1PropertyValue.html>`_
    
    Note:
        This method is for convienence. Properties can also be created from dynamic PropertyValues
        
        Example:
        
        .. code-block:: python
        
            from ooo.dyn.beans.property_value import PropertyValue
            p = PropertyValue(Name='MyProperty', Value=101)
            assert p.Name == 'MyProperty'
            assert p.Value == 101
            assert type(p).__name__ == 'com.sun.star.beans.PropertyValue'
    """
    property_value: 'PropertyValue' = create_uno_struct(
        "com.sun.star.beans.PropertyValue")

    if name != None:
        property_value.Name = name
    if value != None:
        property_value.Value = value
    if handle != None:
        property_value.Handle = handle
    if state != None:
        property_value.State = state

    return property_value


def unotype(name: str) -> uno.Type:
    """
    >>> unotype('com.sun.star.uno.XInterface')
    <Type instance com.sun.star.uno.XInterface
        (<uno.Enum com.sun.star.uno.TypeClass ('INTERFACE')>)>
    """
    return uno.getTypeByName(name)


def unoclass(name: str) -> type:
    """
    >>> unoclass('com.sun.star.text.XText')
    <class 'uno.com.sun.star.text.XText'>
    """
    return uno.getClass(name)

@typing.overload
def supports_service(si:'XServiceInfo', *services: str ) -> bool:
    """
    Tests whether the specified service is supported.

    Args:
        si (XServiceInfo): service that implements XServiceInfo
    
    Other Arguments:
        services (str) comma seperated services to test

    Raises:
        TypeError: If ``si`` is does not implement XServiceInfo

    Returns:
        bool: ``True`` if ``si`` suppoorts service; Otherwise ``False``
    """
@typing.overload
def supports_service(si:'XServiceInfo', *services: object ) -> bool:
    """
    Tests whether the specified service is supported.

    Args:
        si (XServiceInfo): service that implements XServiceInfo

    Other Arguments:
        services (object) comma seperated services to test

    Raises:
        TypeError: If ``si`` is does not implement XServiceInfo
        ValueError: if a service object is invalid.

    Returns:
        bool: ``True`` if ``si`` suppoorts service; Otherwise ``False``
    """

def supports_service(si:'XServiceInfo', *services: typing.Union[str, object] ) -> bool:
    if not hasattr(si, 'supportsService'):
        raise TypeError("supports_service() 'si' does not contain attribute supportsService.")
    if len(services) == 0:
        return False
    result = False
    for srv in services:
        if isinstance(srv, str):
            ns = srv
        elif hasattr(srv, '__ooo_full_ns__'):
            ns = srv.__ooo_full_ns__
        else:
            raise ValueError(f"supports_service() Unable to obtain service name for type: {type(srv).__name__}")
        if si.supportsService(ns):
            result = True
            break
    return result




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class FrameAction(Enum):
    """
    Enum Class


    See Also:
        `API FrameAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame.html#a793fdb3e5cab69d63a9c89b5e4f83dfd>`_
    """
    __ooo_ns__: str = "com.sun.star.frame"
    __ooo_full_ns__: str = "com.sun.star.frame.FrameAction"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.frame.FrameAction"

    COMPONENT_ATTACHED = "COMPONENT_ATTACHED"
    """
    an event of this kind is broadcast whenever a component is attached to a frame
    
    This is almost the same as the instantiation of the component within that frame. The component is attached to the frame immediately before this event is broadcast.
    """
    COMPONENT_DETACHING = "COMPONENT_DETACHING"
    """
    an event of this kind is broadcast whenever a component is detaching from a frame
    
    This is quite the same as the destruction of the component which was in that frame. At the moment when the event is broadcast the component is still attached to the frame but in the next moment it won't.
    """
    COMPONENT_REATTACHED = "COMPONENT_REATTACHED"
    """
    an event of this kind is broadcast whenever a component is attached to a new model.
    
    In this case the component remains the same but operates on a new model component.
    """
    CONTEXT_CHANGED = "CONTEXT_CHANGED"
    """
    an event of this kind is broadcast whenever a component changes its internal context (i.e., the selection).
    
    If the activation status within a frame changes, this counts as a context change too.
    """
    FRAME_ACTIVATED = "FRAME_ACTIVATED"
    """
    an event of this kind is broadcast whenever a component gets activated
    
    Activations are broadcast from the top component which was not active before, down to the inner most component.
    """
    FRAME_DEACTIVATING = "FRAME_DEACTIVATING"
    """
    an event of this kind is broadcasted immediately before the component is deactivated
    
    Deactivations are broadcast from the innermost component which does not stay active up to the outer most component which does not stay active.
    """
    FRAME_UI_ACTIVATED = "FRAME_UI_ACTIVATED"
    """
    an event of this kind is broadcast by an active frame when it is getting UI control (tool control).
    """
    FRAME_UI_DEACTIVATING = "FRAME_UI_DEACTIVATING"
    """
    an event of this kind is broadcast by an active frame when it is losing UI control (tool control).
    """

__all__ = ["FrameAction"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
from __future__ import annotations
from abc import abstractproperty
from .x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9

class XCommand(XAnimationNode_1cf10eb9):
    """
    Execution of the XCommand animation node causes the slide show component to call back the application to perform the command.

    See Also:
        `API XCommand <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XCommand.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.XCommand'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.animations.XCommand'

    @abstractproperty
    def Command(self) -> int:
        """
        This identifies the application specific command.
        
        See documentation of used application for commands.
        """
        ...

    @abstractproperty
    def Parameter(self) -> object:
        """
        The application specific parameter for this command.
        
        See documentation of used application for supported parameters for different commands and target combinations.
        """
        ...

    @abstractproperty
    def Target(self) -> object:
        """
        The application specific target.
        
        See documentation of used application for supported targets.
        """
        ...


__all__ = ['XCommand']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .calendar_item import CalendarItem as CalendarItem_a86c0af1
import typing


class CalendarItem2(CalendarItem_a86c0af1):
    """
    Struct Class

    One entry in a calendar, for example, a day of week or a month or an era.
    
    Derived from com.sun.star.i18n.CalendarItem this provides an additional member for narrow names.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API CalendarItem2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1CalendarItem2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.CalendarItem2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.CalendarItem2'
    """Literal Constant ``com.sun.star.i18n.CalendarItem2``"""

    def __init__(self, ID: typing.Optional[str] = '', AbbrevName: typing.Optional[str] = '', FullName: typing.Optional[str] = '', NarrowName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            ID (str, optional): ID value.
            AbbrevName (str, optional): AbbrevName value.
            FullName (str, optional): FullName value.
            NarrowName (str, optional): NarrowName value.
        """

        if isinstance(ID, CalendarItem2):
            oth: CalendarItem2 = ID
            self.ID = oth.ID
            self.AbbrevName = oth.AbbrevName
            self.FullName = oth.FullName
            self.NarrowName = oth.NarrowName
            return

        kargs = {
            "ID": ID,
            "AbbrevName": AbbrevName,
            "FullName": FullName,
            "NarrowName": NarrowName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._narrow_name = kwargs["NarrowName"]
        inst_keys = ('NarrowName',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def NarrowName(self) -> str:
        """
        The narrow name, for example, \"S\" for Sunday or \"J\" for January.
        """
        return self._narrow_name

    @NarrowName.setter
    def NarrowName(self, value: str) -> None:
        self._narrow_name = value


__all__ = ['CalendarItem2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_dialog_provider import XDialogProvider as XDialogProvider_c70f0c47
if typing.TYPE_CHECKING:
    from .x_dialog import XDialog as XDialog_709d08fc
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XDialogProvider2(XDialogProvider_c70f0c47):
    """
    provides dialogs implementing the com.sun.star.awt.XDialog interface.

    See Also:
        `API XDialogProvider2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDialogProvider2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XDialogProvider2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XDialogProvider2'

    @abstractmethod
    def createDialogWithArguments(self, URL: str, Arguments: typing.Tuple[NamedValue_a37a0af3, ...]) -> XDialog_709d08fc:
        """
        creates a dialog for the given URL, accepting additional creation parameters
        
        The arguments accepted so far are

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createDialogWithHandler(self, URL: str, xHandler: XInterface_8f010a43) -> XDialog_709d08fc:
        """
        creates a dialog for the given URL accepting an Interface used to handle dialog events.
        
        xHandler can handle events in two different ways:
        
        If XDialogEventHandler is supported XDialogEventHandler.callHandlerMethod() is always called first to handle the event. Only if the event cannot be handled by XDialogEventHandler (callHandlerMethod() then has to return false) or if XDialogEventHandler is not supported at all the Introspection based access will be used.
        
        The Introspection based access tries to call a method named according to the HandlerMethodName specified by a vnd.sun.star.UNO:HandlerMethodName URL. First a method
        
        void HandlerMethodName( [in] com.sun.star.awt.XDialog xDialog, [in] any aEvent )
        
        will be searched. The signature is similar to XDialogEventHandler. callHandlerMethod except for MethodName itself that isn't needed here. For more information about these parameters, see com.sun.star.awt.XDialogEventHandler.
        
        If this method is found, it will be called, otherwise a method
        
        void HandlerMethodName( void )
        
        will be searched and called.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XDialogProvider2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FormulaLanguage(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.FormulaLanguage", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.FormulaLanguage``"""
        pass

    class FormulaLanguageEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.FormulaLanguage", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.FormulaLanguage`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import FormulaLanguage as FormulaLanguage
    else:
        # keep document generators happy
        from ...lo.sheet.formula_language import FormulaLanguage as FormulaLanguage

    class FormulaLanguageEnum(IntEnum):
        """
        Enum of Const Class FormulaLanguage

        Constants designating the formula language used with XFormulaOpCodeMapper methods.
        
        **since**
        
            LibreOffice 5.3
        """
        ODFF = FormulaLanguage.ODFF
        """
        Function names and operators as defined by the OASIS OpenDocument Format (ODF) Formula specification (ODFF aka OpenFormula).
        """
        ODF_11 = FormulaLanguage.ODF_11
        """
        Function names and operators as used in ODF documents prior to the ODFF specification, up to ODF v1.1.
        """
        ENGLISH = FormulaLanguage.ENGLISH
        """
        Function names and operators as used in the English language user interface.
        """
        NATIVE = FormulaLanguage.NATIVE
        """
        Function names and operators as used in the current native language user interface.
        """
        XL_ENGLISH = FormulaLanguage.XL_ENGLISH
        """
        Function names and operators as used in the English version of Excel.
        
        This formula language is also used in VBA formulas.
        """
        OOXML = FormulaLanguage.OOXML
        """
        Function names and operators as used in OOXML.
        
        **since**
        
            LibreOffice 4.2
        """
        API = FormulaLanguage.API
        """
        Function names and operators as used with XFunctionAccess and other API context.
        
        Names are mostly identical to ENGLISH and ODF_11, but while ENGLISH names can be adapted to UI needs and ODF_11 has to stay error compatible, the API names strive to stay compatible but may get corrected in case of errors. Earlier versions than LibreOffice 5.3 always used ODF_11 in API context.
        
        **since**
        
            LibreOffice 5.3
        """

__all__ = ['FormulaLanguage', 'FormulaLanguageEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XCompletedConnection(XInterface_8f010a43):
    """
    is used for establishing connections via a factory which is identified by its name.
    
    To complete the information needed for establishing a connection an interaction handler is used.

    See Also:
        `API XCompletedConnection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XCompletedConnection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XCompletedConnection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XCompletedConnection'

    @abstractmethod
    def connectWithCompletion(self, handler: XInteractionHandler_bf80e51) -> XConnection_a36a0b0c:
        """
        attempts to establish a database connection.
        
        If information is missing, such as a user's password, they are completed by user interaction.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XCompletedConnection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..awt.gradient import Gradient as Gradient_7a8a0982
    from ..awt.size import Size as Size_576707ef
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..table.border_line import BorderLine as BorderLine_a3f80af6
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from .x_text_frame import XTextFrame as XTextFrame_9a7e0ab5
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.GraphicLocation import GraphicLocationProto  # type: ignore
    from com.sun.star.drawing.FillStyle import FillStyleProto  # type: ignore
    from com.sun.star.text.WrapTextMode import WrapTextModeProto  # type: ignore

class BaseFrameProperties(UserDefinedAttributesSupplier_9fbe1222):
    """
    Service Class

    specifies the properties that are provided by all text frames, graphic objects, embedded objects and frame styles.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API BaseFrameProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1BaseFrameProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.BaseFrameProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def FrameInteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of frame properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def AllowOverlap(self) -> bool:
        """
        This defines if the frame is allowed to overlap with other anchored objects.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def AnchorFrame(self) -> XTextFrame_9a7e0ab5:
        """
        contains the text frame the current frame is anchored to.
        
        The value is valid only if the AnchorType is TextContentAnchorType.AT_FRAME.
        """
        ...

    @abstractproperty
    def AnchorPageNo(self) -> int:
        """
        contains the number of the page where the objects are anchored.
        
        The value is valid only if the AnchorType is TextContentAnchorType.AT_PAGE.
        """
        ...

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        contains the color of the background of the object.
        """
        ...

    @abstractproperty
    def BackGraphic(self) -> XGraphic_a4da0afc:
        """
        contains the graphic for the background.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the file filter for the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicLocation(self) -> GraphicLocationProto:
        """
        determines the position of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicURL(self) -> str:
        """
        contains the URL for the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        If TRUE, the \"BackColor\" is ignored.
        """
        ...

    @abstractproperty
    def BorderDistance(self) -> int:
        """
        contains the distance from the border to the object.
        """
        ...

    @abstractproperty
    def BottomBorder(self) -> BorderLine_a3f80af6:
        """
        contains the bottom border of the object.
        """
        ...

    @abstractproperty
    def BottomBorderDistance(self) -> int:
        """
        contains the distance from the bottom border to the object.
        """
        ...

    @abstractproperty
    def BottomMargin(self) -> int:
        """
        contains the bottom margin of the object.
        """
        ...

    @abstractproperty
    def ContentProtected(self) -> bool:
        """
        determines if the content is protected.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        contains description for the object
        
        The long description text can be entered to describe an object in more detail to users with screen reader software. The description is visible as an alternative tag for accessibility tools.
        
        **since**
        
            OOo 3.2
        """
        ...

    @abstractproperty
    def FillGradient(self) -> Gradient_7a8a0982:
        """
        If the property FillStyle is set to FillStyle.GRADIENT, this describes the gradient used.
        
        **since**
        
            LibreOffice 4.1
        """
        ...

    @abstractproperty
    def FillGradientName(self) -> str:
        """
        If the property FillStyle is set to FillStyle.GRADIENT, this is the name of the gradient used.
        
        **since**
        
            LibreOffice 4.1
        """
        ...

    @abstractproperty
    def FillStyle(self) -> FillStyleProto:
        """
        This enumeration selects the style the area will be filled with.
        
        Currently only set for gradients.
        
        **since**
        
            LibreOffice 4.1
        """
        ...

    @abstractproperty
    def Height(self) -> int:
        """
        contains the height of the object (1/100 mm).
        
        It is only valid if TextEmbeddedObject.RelativeHeight is zero.
        """
        ...

    @abstractproperty
    def HoriOrient(self) -> int:
        """
        determines the horizontal orientation of the object.
        """
        ...

    @abstractproperty
    def HoriOrientPosition(self) -> int:
        """
        contains the horizontal position of the object (1/100 mm).
        
        It is only valid if \"HoriOrient\" is HoriOrientation_NONE.
        """
        ...

    @abstractproperty
    def HoriOrientRelation(self) -> int:
        """
        determines the environment of the object to which the orientation is related.
        """
        ...

    @abstractproperty
    def HyperLinkName(self) -> str:
        """
        contains the name of the hyperlink that is set at the object.
        """
        ...

    @abstractproperty
    def HyperLinkTarget(self) -> str:
        """
        contains the name of the target for a hyperlink that is set at the object.
        """
        ...

    @abstractproperty
    def HyperLinkURL(self) -> str:
        """
        contains the URL of a hyperlink that is set at the object.
        """
        ...

    @abstractproperty
    def IsSyncHeightToWidth(self) -> bool:
        """
        determines whether the height follows the width.
        """
        ...

    @abstractproperty
    def IsSyncWidthToHeight(self) -> bool:
        """
        determines whether the width follows the height.
        """
        ...

    @abstractproperty
    def LayoutSize(self) -> Size_576707ef:
        """
        returns the actual size of the object.
        
        Since to obtain the correct actual size of the object not only the layouting for the frame needs to be finished but the whole document needs to be formatted as well. Thus if that was not done previously it may take some while to retrieve this value.
        
        **since**
        
            OOo 2.0.4
        """
        ...

    @abstractproperty
    def LeftBorder(self) -> BorderLine_a3f80af6:
        """
        contains the left border of the object.
        """
        ...

    @abstractproperty
    def LeftBorderDistance(self) -> int:
        """
        contains the distance from the left border to the object.
        """
        ...

    @abstractproperty
    def LeftMargin(self) -> int:
        """
        contains the left margin of the object.
        """
        ...

    @abstractproperty
    def Opaque(self) -> bool:
        """
        determines if the object is opaque or transparent for text.
        """
        ...

    @abstractproperty
    def PageToggle(self) -> bool:
        """
        determines if the object is mirrored on even pages.
        """
        ...

    @abstractproperty
    def PositionProtected(self) -> bool:
        """
        determines if the position is protected.
        """
        ...

    @abstractproperty
    def Print(self) -> bool:
        """
        determines if the object is included in printing.
        """
        ...

    @abstractproperty
    def RelativeHeight(self) -> int:
        """
        contains the relative height of the object.
        
        It is only valid if it is greater than zero.
        """
        ...

    @abstractproperty
    def RelativeHeightRelation(self) -> int:
        """
        contains the relation of the relative height of the object.
        
        It is only valid if RelativeHeight is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def RelativeWidth(self) -> int:
        """
        contains the relative width of the object.
        
        It is only valid if it is greater than zero.
        """
        ...

    @abstractproperty
    def RelativeWidthRelation(self) -> int:
        """
        contains the relation of the relative width of the object.
        
        It is only valid if RelativeWidth is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def RightBorder(self) -> BorderLine_a3f80af6:
        """
        contains the right border of the object.
        """
        ...

    @abstractproperty
    def RightBorderDistance(self) -> int:
        """
        contains the distance from the right border to the object.
        """
        ...

    @abstractproperty
    def RightMargin(self) -> int:
        """
        contains the right margin of the object.
        """
        ...

    @abstractproperty
    def ServerMap(self) -> bool:
        """
        determines if the object gets an image map from a server.
        """
        ...

    @abstractproperty
    def ShadowFormat(self) -> ShadowFormat_bb840bdf:
        """
        contains the type of the shadow of the object.
        """
        ...

    @abstractproperty
    def ShadowTransparence(self) -> int:
        """
        This defines the degree of transparence of the shadow in percent.
        
        This is the same as setting the Color member of the ShadowFormat property to an ARGB color.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def Size(self) -> Size_576707ef:
        """
        contains the size of the object.
        """
        ...

    @abstractproperty
    def SizeProtected(self) -> bool:
        """
        determines if the size is protected.
        """
        ...

    @abstractproperty
    def Surround(self) -> WrapTextModeProto:
        """
        determines the type of the surrounding text.
        """
        ...

    @abstractproperty
    def SurroundAnchorOnly(self) -> bool:
        """
        determines if the text of the paragraph in which the object is anchored, wraps around the object.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        contains short title for the object
        
        This short title is visible as an alternative tag in HTML format. Accessibility tools can read this text.
        
        **since**
        
            OOo 3.2
        """
        ...

    @abstractproperty
    def Tooltip(self) -> str:
        """
        Contains popup text for the frame, used to for tooltip purposes if it's non-empty.
        
        **since**
        
            LibreOffice 7.4
        """
        ...

    @abstractproperty
    def TopBorder(self) -> BorderLine_a3f80af6:
        """
        contains the top border of the object.
        """
        ...

    @abstractproperty
    def TopBorderDistance(self) -> int:
        """
        contains the distance from the top border to the object.
        """
        ...

    @abstractproperty
    def TopMargin(self) -> int:
        """
        contains the top margin of the object.
        """
        ...

    @abstractproperty
    def VertOrient(self) -> int:
        """
        determines the vertical orientation of the object.
        """
        ...

    @abstractproperty
    def VertOrientPosition(self) -> int:
        """
        contains the vertical position of the object (1/100 mm).
        
        It is only valid if TextEmbeddedObject.VertOrient is VertOrientation.NONE.
        """
        ...

    @abstractproperty
    def VertOrientRelation(self) -> int:
        """
        determines the environment of the object to which the orientation is related.
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        contains the width of the object (1/100 mm).
        
        It is only valid if TextEmbeddedObject.RelativeWidth is zero.
        """
        ...

    @abstractproperty
    def WrapInfluenceOnPosition(self) -> int:
        """
        determines the influence of the text wrap on the positioning of the shape
        
        The value of this property is only evaluated for the positioning of the shape, if the text document setting ConsiderTextWrapOnObjPos is TRUE. Valid values are given by WrapInfluenceOnPosition
        
        **since**
        
            OOo 2.0
        """
        ...


__all__ = ['BaseFrameProperties']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DataPilotTableHeaderData(object):
    """
    Struct Class

    information about a cell within the column or row header area of a DataPilot table.
    
    This struct contains information about a particular cell located within the column or row header area of a DataPilot table. This is the type that is contained in DataPilotTablePositionData.PositionData when the value of DataPilotTablePositionData.PositionType is either DataPilotTablePositionType.ROW_HEADER or DataPilotTablePositionType.COLUMN_HEADER.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTableHeaderData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableHeaderData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotTableHeaderData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.DataPilotTableHeaderData'
    """Literal Constant ``com.sun.star.sheet.DataPilotTableHeaderData``"""

    def __init__(self, Dimension: typing.Optional[int] = 0, Hierarchy: typing.Optional[int] = 0, Level: typing.Optional[int] = 0, Flags: typing.Optional[int] = 0, MemberName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Dimension (int, optional): Dimension value.
            Hierarchy (int, optional): Hierarchy value.
            Level (int, optional): Level value.
            Flags (int, optional): Flags value.
            MemberName (str, optional): MemberName value.
        """
        super().__init__()

        if isinstance(Dimension, DataPilotTableHeaderData):
            oth: DataPilotTableHeaderData = Dimension
            self.Dimension = oth.Dimension
            self.Hierarchy = oth.Hierarchy
            self.Level = oth.Level
            self.Flags = oth.Flags
            self.MemberName = oth.MemberName
            return

        kargs = {
            "Dimension": Dimension,
            "Hierarchy": Hierarchy,
            "Level": Level,
            "Flags": Flags,
            "MemberName": MemberName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._dimension = kwargs["Dimension"]
        self._hierarchy = kwargs["Hierarchy"]
        self._level = kwargs["Level"]
        self._flags = kwargs["Flags"]
        self._member_name = kwargs["MemberName"]


    @property
    def Dimension(self) -> int:
        """
        number of dimensions
        """
        return self._dimension

    @Dimension.setter
    def Dimension(self, value: int) -> None:
        self._dimension = value

    @property
    def Hierarchy(self) -> int:
        """
        hierarchy
        """
        return self._hierarchy

    @Hierarchy.setter
    def Hierarchy(self, value: int) -> None:
        self._hierarchy = value

    @property
    def Level(self) -> int:
        """
        level
        """
        return self._level

    @Level.setter
    def Level(self, value: int) -> None:
        self._level = value

    @property
    def Flags(self) -> int:
        """
        flag
        """
        return self._flags

    @Flags.setter
    def Flags(self, value: int) -> None:
        self._flags = value

    @property
    def MemberName(self) -> str:
        """
        member name
        """
        return self._member_name

    @MemberName.setter
    def MemberName(self, value: str) -> None:
        self._member_name = value


__all__ = ['DataPilotTableHeaderData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from .x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception_c2a512da

class DispatchProvider(XDispatchProvider_fc690de6, XDispatchProviderInterception_c2a512da):
    """
    Service Class

    provides XDispatch objects for certain functions which are useful at the UI
    
    Such dispatch objects must be queried explicitly and used for queried purposes only. They can handle requests with guaranteed notifications (XNotifyingDispatch) or with possible (but not guaranteed) notifications (XDispatch).

    See Also:
        `API DispatchProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1DispatchProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.DispatchProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['DispatchProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.mail
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..datatransfer.x_transferable import XTransferable as XTransferable_2d800f38


class MailAttachment(object):
    """
    Struct Class

    A MailAttachment specifies a mail message attachment.
    
    **since**
    
        OOo 2.0

    See Also:
        `API MailAttachment <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1mail_1_1MailAttachment.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mail'
    __ooo_full_ns__: str = 'com.sun.star.mail.MailAttachment'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.mail.MailAttachment'
    """Literal Constant ``com.sun.star.mail.MailAttachment``"""

    def __init__(self, Data: typing.Optional[XTransferable_2d800f38] = None, ReadableName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Data (XTransferable, optional): Data value.
            ReadableName (str, optional): ReadableName value.
        """
        super().__init__()

        if isinstance(Data, MailAttachment):
            oth: MailAttachment = Data
            self.Data = oth.Data
            self.ReadableName = oth.ReadableName
            return

        kargs = {
            "Data": Data,
            "ReadableName": ReadableName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._data = kwargs["Data"]
        self._readable_name = kwargs["ReadableName"]


    @property
    def Data(self) -> XTransferable_2d800f38:
        """
        The actual data which should be attached to a mail message.
        
        It is expected that the transferable delivers the data as sequence of bytes. Although a transferable may support multiple data flavors only the first data flavor supplied will be used to retrieve the data and it is expected that the type of the data is a sequence of bytes.
        """
        return self._data

    @Data.setter
    def Data(self, value: XTransferable_2d800f38) -> None:
        self._data = value

    @property
    def ReadableName(self) -> str:
        """
        The name of the attachment as seen by the recipient of the mail message.
        
        ReadableName must not be empty.
        """
        return self._readable_name

    @ReadableName.setter
    def ReadableName(self, value: str) -> None:
        self._readable_name = value


__all__ = ['MailAttachment']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control_image_control import UnoControlImageControl as UnoControlImageControl_29c00f2b
from ..x_bound_control import XBoundControl as XBoundControl_bba00bed

class ImageControl(UnoControlImageControl_29c00f2b, XBoundControl_bba00bed):
    """
    Service Class

    describes a control used for displaying images stored in a database.
    
    The model of the control has to support the com.sun.star.form.component.DatabaseImageControl service.
    
    If the model of the control is valid bound to a database field, the control allows to select an image (browsing the file system) upon double clicking into it, and forwards the URL of the chosen image to the ImageURL property of its model.

    See Also:
        `API ImageControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1ImageControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.ImageControl'
    __ooo_type_name__: str = 'service'


__all__ = ['ImageControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from ..lang.x_service_name import XServiceName as XServiceName_af090b54
from .x_add_in import XAddIn as XAddIn_7a560939
from .x_compatibility_names import XCompatibilityNames as XCompatibilityNames_1b100ec7

class AddIn(XServiceName_af090b54, XAddIn_7a560939, XCompatibilityNames_1b100ec7):
    """
    Service Class

    is the base for AddIn services that supply functions which can be called by other components.
    
    Any AddIn implementation must implement a service describing its specific set of functions. That service must contain the AddIn service, and the functions that are implemented, in one or more interfaces. The com.sun.star.lang.XServiceName interface must describe that service, and the XAddIn interface must describe the individual functions.
    
    Each AddIn function can take parameters of the following types:
    
    Each AddIn function must have one of the following return types:
    
    The sequences must contain arrays as described above for the parameter types. An XVolatileResult return value must contain an object implementing the VolatileResult service, that contains a volatile result. Subsequent calls with the same parameters must return the same object. An any return value can contain any of the other types.

    See Also:
        `API AddIn <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1AddIn.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.AddIn'
    __ooo_type_name__: str = 'service'


__all__ = ['AddIn']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..util.color import Color as Color_68e908c5

class UnoControlDialogModel(UnoControlModel_c8ce0c58, XContainer_d6fb0cc6, XNameContainer_cb90e47, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    specifies the standard model of a UnoControlDialog.
    
    **since**
    
        OOo 2.3

    See Also:
        `API UnoControlDialogModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlDialogModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the background color (RGB) of the dialog.
        """
        ...

    @abstractproperty
    def Closeable(self) -> bool:
        """
        specifies if the dialog is closeable.
        """
        ...

    @abstractproperty
    def DesktopAsParent(self) -> bool:
        """
        If set to true the dialog will have the desktop as parent.
        
        **since**
        
            OOo 2.3
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether a dialog is enabled or disabled.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        specifies the font attributes of the text in the caption bar of the dialog.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the caption bar of the dialog.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the caption bar of the dialog.
        """
        ...

    @abstractproperty
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        specifies a graphic to be displayed as a background image
        
        If this property is present, it interacts with the ImageURL in the following way:
        
        **since**
        
            OOo 2.4
        """
        ...

    @abstractproperty
    def HScroll(self) -> bool:
        """
        specifies that a horizontal scrollbar should be added to the dialog
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the dialog.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the dialog.
        """
        ...

    @abstractproperty
    def ImageURL(self) -> str:
        """
        specifies a URL that references a graphic that should be used as a background image.
        
        **since**
        
            OOo 2.4
        """
        ...

    @abstractproperty
    def Moveable(self) -> bool:
        """
        specifies if the dialog is moveable.
        """
        ...

    @abstractproperty
    def ScrollHeight(self) -> int:
        """
        specifies the total height of the scrollable dialog content
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def ScrollLeft(self) -> int:
        """
        specifies the horizontal position of the scrolled dialog content
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def ScrollTop(self) -> int:
        """
        specifies the vertical position of the scrolled dialog content
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def ScrollWidth(self) -> int:
        """
        specifies the total width of the scrollable dialog content
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def Sizeable(self) -> bool:
        """
        specifies if the dialog is sizeable.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the text color (RGB) of the dialog.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> Color_68e908c5:
        """
        specifies the text line color (RGB) of the dialog.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        specifies the text that is displayed in the caption bar of the dialog.
        """
        ...

    @abstractproperty
    def VScroll(self) -> bool:
        """
        specifies that a vertical scrollbar should be added to the dialog
        
        **since**
        
            LibreOffice 4.0
        """
        ...


__all__ = ['UnoControlDialogModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DataPilotFieldReference(object):
    """
    Struct Class

    controls how a data pilot field's results are shown in relation to a selected reference result.

    See Also:
        `API DataPilotFieldReference <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReference.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotFieldReference'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.DataPilotFieldReference'
    """Literal Constant ``com.sun.star.sheet.DataPilotFieldReference``"""

    def __init__(self, ReferenceType: typing.Optional[int] = 0, ReferenceField: typing.Optional[str] = '', ReferenceItemType: typing.Optional[int] = 0, ReferenceItemName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            ReferenceType (int, optional): ReferenceType value.
            ReferenceField (str, optional): ReferenceField value.
            ReferenceItemType (int, optional): ReferenceItemType value.
            ReferenceItemName (str, optional): ReferenceItemName value.
        """
        super().__init__()

        if isinstance(ReferenceType, DataPilotFieldReference):
            oth: DataPilotFieldReference = ReferenceType
            self.ReferenceType = oth.ReferenceType
            self.ReferenceField = oth.ReferenceField
            self.ReferenceItemType = oth.ReferenceItemType
            self.ReferenceItemName = oth.ReferenceItemName
            return

        kargs = {
            "ReferenceType": ReferenceType,
            "ReferenceField": ReferenceField,
            "ReferenceItemType": ReferenceItemType,
            "ReferenceItemName": ReferenceItemName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._reference_type = kwargs["ReferenceType"]
        self._reference_field = kwargs["ReferenceField"]
        self._reference_item_type = kwargs["ReferenceItemType"]
        self._reference_item_name = kwargs["ReferenceItemName"]


    @property
    def ReferenceType(self) -> int:
        """
        contains the type of the reference.
        """
        return self._reference_type

    @ReferenceType.setter
    def ReferenceType(self, value: int) -> None:
        self._reference_type = value

    @property
    def ReferenceField(self) -> str:
        """
        contains the reference field
        """
        return self._reference_field

    @ReferenceField.setter
    def ReferenceField(self, value: str) -> None:
        self._reference_field = value

    @property
    def ReferenceItemType(self) -> int:
        """
        selects between a named reference item and using the previous or next item for each item from the reference field.
        """
        return self._reference_item_type

    @ReferenceItemType.setter
    def ReferenceItemType(self, value: int) -> None:
        self._reference_item_type = value

    @property
    def ReferenceItemName(self) -> str:
        """
        contains the name of the reference item, when the DataPilotFieldReference.ReferenceItemType is NAMED otherwise is empty
        """
        return self._reference_item_name

    @ReferenceItemName.setter
    def ReferenceItemName(self, value: str) -> None:
        self._reference_item_name = value


__all__ = ['DataPilotFieldReference']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class FormulaMapGroupSpecialOffset(object):
    """
    Const Class

    Constants designating the offsets within the sequence returned by XFormulaOpCodeMapper.getAvailableMappings() when called for group FormulaMapGroup.SPECIAL.
    
    The number of constants may grow in future versions!
    
    **since**
    
        LibreOffice 7.3

    See Also:
        `API FormulaMapGroupSpecialOffset <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FormulaMapGroupSpecialOffset'
    __ooo_type_name__: str = 'const'

    PUSH = 0
    """
    Formula tokens containing the op-code obtained from this offset describe a formula operand token that will be pushed onto the formula stack while the formula is interpreted.
    
    The FormulaToken.Data member shall contain one of the following values:
    """
    CALL = 1
    STOP = 2
    """
    Formula tokens containing the op-code obtained from this offset instruct the formula interpreter to immediately stop interpreting the formula.
    
    The FormulaToken.Data member is not used and should be empty.
    """
    EXTERNAL = 3
    """
    Formula tokens containing the op-code obtained from this offset describe the reference to an external function (e.g.
    
    add-in function) used in formulas.
    
    The FormulaToken.Data member shall contain a string with the programmatic name of the function, e.g. \"com.sun.star.sheet.addin.Analysis.getEomonth\" for the EOMONTH function from the Analysis add-in.
    """
    NAME = 4
    """
    Formula tokens containing the op-code obtained from this offset describe the reference to a defined name (also known as named range) used in formulas.
    
    The FormulaToken.Data member shall contain an integer value of type long specifying the index of the defined name. This index can be obtained from the defined name using its NamedRange.TokenIndex property.
    """
    NO_NAME = 5
    """
    Formula tokens containing the op-code obtained from this offset describe an invalid name that resolves to the NAME? error in formulas.
    
    The FormulaToken.Data member is not used and should be empty.
    """
    MISSING = 6
    """
    Formula tokens containing the op-code obtained from this offset describe an empty function parameter.
    
    Example: In the formula =SUM(1;;2) the second parameter is empty and represented by a formula token containing the \"missing\" op-code.
    
    The FormulaToken.Data member is not used and should be empty.
    """
    BAD = 7
    """
    Formula tokens containing the op-code obtained from this offset describe \"bad\" data in a formula, e.g.
    
    data the formula parser was not able to parse.
    
    The FormulaToken.Data member shall contain a string with the bad data. This string will be displayed literally in the formula.
    """
    SPACES = 8
    """
    Formula tokens containing the op-code obtained from this offset describe whitespace characters within the string representation of a formula.
    
    Whitespace characters in formulas are used for readability and do not affect the result of the formula.
    
    The FormulaToken.Data member shall contain a positive integer value of type long specifying the number of space characters.
    """
    MAT_REF = 9
    DB_AREA = 10
    """
    Formula tokens containing the op-code obtained from this offset describe the reference to a database range used in formulas.
    
    The FormulaToken.Data member shall contain an integer value of type long specifying the index of the database range. This index can be obtained from the database range using its DatabaseRange.TokenIndex property.
    """
    MACRO = 11
    """
    Formula tokens containing the op-code obtained from this offset describe the reference to a macro function called in a formula.
    
    The FormulaToken.Data member shall contain a string specifying the name of the macro function.
    """
    COL_ROW_NAME = 12
    WHITESPACE = 13
    """
    Formula tokens containing the op-code obtained from this offset describe whitespace characters within the string representation of a formula.
    
    Whitespace characters in formulas are used for readability and do not affect the result of the formula.
    
    The FormulaToken.Data member shall contain a string of one (repeated) whitespace character. The length of the string determines the number of repetitions.
    
    Allowed whitespace characters are SPACE (U+0020), CHARACTER TABULATION (U+0009), LINE FEED (U+000A), and CARRIAGE RETURN (U+000D). See also ODF v1.3 OpenFormula 5.14 Whitespace.
    
    **since**
    
        LibreOffice 7.3
    """

__all__ = ['FormulaMapGroupSpecialOffset']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
import uno
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_data_pilot_field import XDataPilotField as XDataPilotField_e0350cdf
from .x_data_pilot_field_grouping import XDataPilotFieldGrouping as XDataPilotFieldGrouping_55b3102a
if typing.TYPE_CHECKING:
    from .data_pilot_field_auto_show_info import DataPilotFieldAutoShowInfo as DataPilotFieldAutoShowInfo_88d7114d
    from .data_pilot_field_group_info import DataPilotFieldGroupInfo as DataPilotFieldGroupInfo_56691020
    from .data_pilot_field_layout_info import DataPilotFieldLayoutInfo as DataPilotFieldLayoutInfo_671e1091
    from .data_pilot_field_reference import DataPilotFieldReference as DataPilotFieldReference_562f1016
    from .data_pilot_field_sort_info import DataPilotFieldSortInfo as DataPilotFieldSortInfo_466d0fbb
    from com.sun.star.sheet.GeneralFunction import GeneralFunctionProto  # type: ignore
    from com.sun.star.sheet.DataPilotFieldOrientation import DataPilotFieldOrientationProto  # type: ignore

class DataPilotField(XPropertySet_bc180bfa, XNamed_a6520b08, XDataPilotField_e0350cdf, XDataPilotFieldGrouping_55b3102a):
    """
    Service Class

    represents a single field in a data pilot table.
    
    If the data pilot table is based on a spreadsheet cell range, a field is represented by a column of the range and is named using the topmost cell of the column.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API DataPilotField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotField'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Subtotals(self) -> typing.Tuple[GeneralFunctionProto, ...]:
        """
        specifies the functions used to calculate subtotals for this field.
        
        This property is supported by column and row fields only.
        
        An empty sequence means no subtotals. The same effect can be achieved by setting the property Function to the value GeneralFunction.NONE. If the length of the sequence is greater than 1, then the sequence MUST NOT contain one of the values GeneralFunction.NONE or GeneralFunction.AUTO.
        
        The order of the functions in this sequence is reflected in the DataPilot table. Multiple entries of the same function are ignored when setting the property.
        """
        ...

    @abstractproperty
    def Subtotals2(self) -> uno.ByteSequence:
        """
        specifies the functions used to calculate subtotals for this field.
        
        This property is supported by column and row fields only.
        
        An empty sequence means no subtotals. The same effect can be achieved by setting the property Function2 to the value GeneralFunction.NONE. If the length of the sequence is greater than 1, then the sequence MUST NOT contain one of the values GeneralFunction2.NONE or GeneralFunction2.AUTO.
        
        The order of the functions in this sequence is reflected in the DataPilot table. Multiple entries of the same function are ignored when setting the property.
        
        **since**
        
            LibreOffice 5.3
        """
        ...

    @abstractproperty
    def AutoShowInfo(self) -> DataPilotFieldAutoShowInfo_88d7114d:
        """
        enables the automatic inclusion of only a number of items with the highest or lowest result values.
        """
        ...

    @abstractproperty
    def Function(self) -> GeneralFunctionProto:
        """
        specifies the function used to calculate results for this field.
        
        For column and row fields, this is the function for subtotals (GeneralFunction.NONE means no subtotals). For data fields, this is the function shown in the data pilot table.
        """
        ...

    @abstractproperty
    def Function2(self) -> int:
        """
        specifies the function used to calculate results for this field.
        
        For column and row fields, this is the function for subtotals (GeneralFunction2.NONE means no subtotals). For data fields, this is the function shown in the data pilot table.
        
        **since**
        
            LibreOffice 5.3
        """
        ...

    @abstractproperty
    def GroupInfo(self) -> DataPilotFieldGroupInfo_56691020:
        """
        contains the grouping information of the DataPilot field.
        
        By changing the value of this property it is possible to modify the grouping settings of this field.
        """
        ...

    @abstractproperty
    def HasAutoShowInfo(self) -> bool:
        """
        specifies whether this field has auto show information.
        """
        ...

    @abstractproperty
    def HasLayoutInfo(self) -> bool:
        """
        specifies whether this field has layout information.
        """
        ...

    @abstractproperty
    def HasReference(self) -> bool:
        """
        specifies whether this field has a reference.
        """
        ...

    @abstractproperty
    def HasSortInfo(self) -> bool:
        """
        specifies whether this field has sorting information.
        """
        ...

    @abstractproperty
    def IsGroupField(self) -> bool:
        """
        specifies whether this field is a group field.
        """
        ...

    @abstractproperty
    def LayoutInfo(self) -> DataPilotFieldLayoutInfo_671e1091:
        """
        controls how the field's items are laid out in the result table.
        """
        ...

    @abstractproperty
    def Orientation(self) -> DataPilotFieldOrientationProto:
        """
        specifies the orientation of the field.
        
        If the orientation of a field has been changed using this property, the field will be moved to the last position in the collection of all fields with the specified orientation.
        """
        ...

    @abstractproperty
    def Reference(self) -> DataPilotFieldReference_562f1016:
        """
        controls how the results are shown in relation to a selected reference result.
        """
        ...

    @abstractproperty
    def SelectedPage(self) -> str:
        """
        specifies the selected page which is used to filter the data pilot.
        """
        ...

    @abstractproperty
    def ShowEmpty(self) -> bool:
        """
        specifies whether to show this field also if it is empty or not.
        """
        ...

    @abstractproperty
    def SortInfo(self) -> DataPilotFieldSortInfo_466d0fbb:
        """
        controls how the field's items are sorted.
        """
        ...

    @abstractproperty
    def UseSelectedPage(self) -> bool:
        """
        specifies whether to use the selected page to filter the data pilot or show all.
        """
        ...

    @abstractproperty
    def UsedHierarchy(self) -> str:
        """
        specifies which hierarchy of the dimension is used.
        """
        ...


__all__ = ['DataPilotField']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class VertOrientationFormat(object):
    """
    Struct Class

    describes the vertical orientation of an object.
    
    If VerticalOrientation == VERT_NONE, then the value \"YPos\" describes the distance from the top of the context. Otherwise \"YPos\" is ignored.

    See Also:
        `API VertOrientationFormat <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.VertOrientationFormat'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.VertOrientationFormat'
    """Literal Constant ``com.sun.star.text.VertOrientationFormat``"""

    def __init__(self, YPos: typing.Optional[int] = 0, VerticalOrientation: typing.Optional[int] = 0, VerticalRelation: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            YPos (int, optional): YPos value.
            VerticalOrientation (int, optional): VerticalOrientation value.
            VerticalRelation (int, optional): VerticalRelation value.
        """
        super().__init__()

        if isinstance(YPos, VertOrientationFormat):
            oth: VertOrientationFormat = YPos
            self.YPos = oth.YPos
            self.VerticalOrientation = oth.VerticalOrientation
            self.VerticalRelation = oth.VerticalRelation
            return

        kargs = {
            "YPos": YPos,
            "VerticalOrientation": VerticalOrientation,
            "VerticalRelation": VerticalRelation,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._y_pos = kwargs["YPos"]
        self._vertical_orientation = kwargs["VerticalOrientation"]
        self._vertical_relation = kwargs["VerticalRelation"]


    @property
    def YPos(self) -> int:
        """
        contains the distance from top.
        
        Only valid if the property VerticalOrientation contains the value VERT_NONE.
        """
        return self._y_pos

    @YPos.setter
    def YPos(self, value: int) -> None:
        self._y_pos = value

    @property
    def VerticalOrientation(self) -> int:
        """
        determines the vertical alignment of an object.
        
        The values refer to com.sun.star.VertOrientation.
        """
        return self._vertical_orientation

    @VerticalOrientation.setter
    def VerticalOrientation(self, value: int) -> None:
        self._vertical_orientation = value

    @property
    def VerticalRelation(self) -> int:
        """
        determines the reference position of the vertical alignment.
        """
        return self._vertical_relation

    @VerticalRelation.setter
    def VerticalRelation(self, value: int) -> None:
        self._vertical_relation = value


__all__ = ['VertOrientationFormat']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XTableChart(XInterface_8f010a43):
    """
    provides access to the settings of a chart object in a table or spreadsheet.

    See Also:
        `API XTableChart <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XTableChart.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XTableChart'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XTableChart'

    @abstractmethod
    def getHasColumnHeaders(self) -> bool:
        """
        returns, whether the cells of the topmost row of the source data are interpreted as column headers.
        """
        ...
    @abstractmethod
    def getHasRowHeaders(self) -> bool:
        """
        returns, whether the cells of the leftmost column of the source data are interpreted as row headers.
        """
        ...
    @abstractmethod
    def getRanges(self) -> typing.Tuple[CellRangeAddress_ec450d43, ...]:
        """
        returns the cell ranges that contain the data for the chart.
        """
        ...
    @abstractmethod
    def setHasColumnHeaders(self, bHasColumnHeaders: bool) -> None:
        """
        specifies whether the cells of the topmost row of the source data are interpreted as column headers.
        """
        ...
    @abstractmethod
    def setHasRowHeaders(self, bHasRowHeaders: bool) -> None:
        """
        specifies whether the cells of the leftmost column of the source data are interpreted as row headers.
        """
        ...
    @abstractmethod
    def setRanges(self, aRanges: typing.Tuple[CellRangeAddress_ec450d43, ...]) -> None:
        """
        sets the cell ranges that contain the data for the chart.
        """
        ...

__all__ = ['XTableChart']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_focus_listener import XFocusListener as XFocusListener_bb8e0bf2
    from .x_key_handler import XKeyHandler as XKeyHandler_98520a93
    from .x_top_window import XTopWindow as XTopWindow_8ebb0a57
    from .x_top_window_listener import XTopWindowListener as XTopWindowListener_efc20d9d

class XExtendedToolkit(XInterface_8f010a43):
    """
    The XExtendedToolkit is an extension of the com.sun.star.awt.XToolkit interface.
    
    It basically provides access to three event broadcasters which are used for instance in the context of accessibility. It is, however, not restricted to accessibility.
    
    The first event broadcaster lets you keep track of the open top-level windows (frames). To get the set of currently open top-level window use the XExtendedToolkit.getTopWindowCount() and XExtendedToolkit.getTopWindow() methods.
    
    The second event broadcaster informs its listeners of key events. Its listeners can, unlike with most other broadcasters/listeners, consume events, so that other listeners will not be called for consumed events.
    
    The last event broadcaster sends events on focus changes of all elements that can have the input focus.
    
    **since**
    
        OOo 1.1.2
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XExtendedToolkit <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XExtendedToolkit'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XExtendedToolkit'

    @abstractmethod
    def addFocusListener(self, xListener: XFocusListener_bb8e0bf2) -> None:
        """
        Add a new listener that is called on com.sun.star.awt.FocusEvent.
        
        Use this focus broadcaster to keep track of the object that currently has the input focus.
        """
        ...
    @abstractmethod
    def addKeyHandler(self, xHandler: XKeyHandler_98520a93) -> None:
        """
        Add a new listener that is called on com.sun.star.awt.KeyEvent.
        
        Every listener is given the opportunity to consume the event, i.e. prevent the not yet called listeners from being called.
        """
        ...
    @abstractmethod
    def addTopWindowListener(self, xListener: XTopWindowListener_efc20d9d) -> None:
        """
        Add a new listener that is called for events that involve com.sun.star.awt.XTopWindow.
        
        After having obtained the current list of existing top-level windows you can keep this list up-to-date by listening to opened or closed top-level windows. Wait for activations or deactivations of top-level windows to keep track of the currently active frame.
        """
        ...
    @abstractmethod
    def fireFocusGained(self, source: XInterface_8f010a43) -> None:
        """
        Broadcasts the a focusGained on all registered focus listeners.
        """
        ...
    @abstractmethod
    def fireFocusLost(self, source: XInterface_8f010a43) -> None:
        """
        Broadcasts the a focusGained on all registered focus listeners.
        """
        ...
    @abstractmethod
    def getActiveTopWindow(self) -> XTopWindow_8ebb0a57:
        """
        Return the currently active top-level window, i.e.
        
        which has currently the input focus.
        """
        ...
    @abstractmethod
    def getTopWindow(self, nIndex: int) -> XTopWindow_8ebb0a57:
        """
        Return a reference to the specified top-level window.
        
        Note that the number of top-level windows may change between a call to getTopWindowCount() and successive calls to this function.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getTopWindowCount(self) -> int:
        """
        This function returns the number of currently existing top-level windows.
        """
        ...
    @abstractmethod
    def removeFocusListener(self, xListener: XFocusListener_bb8e0bf2) -> None:
        """
        Remove the specified listener from the list of listeners.
        """
        ...
    @abstractmethod
    def removeKeyHandler(self, xHandler: XKeyHandler_98520a93) -> None:
        """
        Remove the specified listener from the list of listeners.
        """
        ...
    @abstractmethod
    def removeTopWindowListener(self, xListener: XTopWindowListener_efc20d9d) -> None:
        """
        Remove the specified listener from the list of listeners.
        """
        ...

__all__ = ['XExtendedToolkit']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class reservedWords(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.reservedWords", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.reservedWords``"""
        pass

    class reservedWordsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.reservedWords", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.reservedWords`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import reservedWords as reservedWords
    else:
        # keep document generators happy
        from ...lo.i18n.reserved_words import reservedWords as reservedWords

    class reservedWordsEnum(IntEnum):
        """
        Enum of Const Class reservedWords

        Offsets into the sequence of strings returned by XLocaleData.getReservedWord().
        """
        TRUE_WORD = reservedWords.TRUE_WORD
        """
        \"true\"
        """
        FALSE_WORD = reservedWords.FALSE_WORD
        """
        \"false\"
        """
        QUARTER1_WORD = reservedWords.QUARTER1_WORD
        """
        \"1st quarter\"
        """
        QUARTER2_WORD = reservedWords.QUARTER2_WORD
        """
        \"2nd quarter\"
        """
        QUARTER3_WORD = reservedWords.QUARTER3_WORD
        """
        \"3rd quarter\"
        """
        QUARTER4_WORD = reservedWords.QUARTER4_WORD
        """
        \"4th quarter\"
        """
        ABOVE_WORD = reservedWords.ABOVE_WORD
        """
        \"above\"
        """
        BELOW_WORD = reservedWords.BELOW_WORD
        """
        \"below\"
        """
        QUARTER1_ABBREVIATION = reservedWords.QUARTER1_ABBREVIATION
        """
        \"Q1\"
        """
        QUARTER2_ABBREVIATION = reservedWords.QUARTER2_ABBREVIATION
        """
        \"Q2\"
        """
        QUARTER3_ABBREVIATION = reservedWords.QUARTER3_ABBREVIATION
        """
        \"Q3\"
        """
        QUARTER4_ABBREVIATION = reservedWords.QUARTER4_ABBREVIATION
        """
        \"Q4\"
        """
        COUNT = reservedWords.COUNT
        """
        Yes, this must be the count of known reserved words and one more than the maximum number used above! Count of known reserved words.
        """

__all__ = ['reservedWords', 'reservedWordsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from .xui_element import XUIElement as XUIElement_820509a6
from ..util.x_updatable import XUpdatable as XUpdatable_9a420ab0

class UIElement(XComponent_98dc0ab5, XInitialization_d46c0cca, XUIElement_820509a6, XUpdatable_9a420ab0):
    """
    Service Class

    specifies a user interface element.
    
    A user interface element consists of a unique identifier and a type specifier. It provides an interface to retrieve a special purpose interface which depends on the specific user interface element type. Every user interface must be initialized before it can be used.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UIElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1UIElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.UIElement'
    __ooo_type_name__: str = 'service'


__all__ = ['UIElement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class ColorMode(Enum):
    """
    Enum Class


    See Also:
        `API ColorMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a0e887cb85702e0dccbf34d7dbe40443f>`_
    """
    __ooo_ns__: str = "com.sun.star.drawing"
    __ooo_full_ns__: str = "com.sun.star.drawing.ColorMode"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.drawing.ColorMode"

    GREYS = "GREYS"
    """
    the graphic is rendered in grayscale on the output device,
    """
    MONO = "MONO"
    """
    the graphic is rendered in black and white only,
    """
    STANDARD = "STANDARD"
    """
    the graphic is rendered in the default color style of the output device,
    
    use the length measurement.
    
    the connector is drawn with three lines, with the middle line perpendicular to the other two
    """
    WATERMARK = "WATERMARK"
    """
    the graphic is rendered in a watermark like style,
    """

__all__ = ["ColorMode"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ListboxControlActions(metaclass=UnoConstMeta, type_name="com.sun.star.ui.dialogs.ListboxControlActions", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ui.dialogs.ListboxControlActions``"""
        pass

    class ListboxControlActionsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ui.dialogs.ListboxControlActions", name_space="com.sun.star.ui.dialogs"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ui.dialogs.ListboxControlActions`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ui.dialogs import ListboxControlActions as ListboxControlActions
    else:
        # keep document generators happy
        from ....lo.ui.dialogs.listbox_control_actions import ListboxControlActions as ListboxControlActions

    class ListboxControlActionsEnum(IntEnum):
        """
        Enum of Const Class ListboxControlActions

        These constants are deprecated and should not be used anymore.
        
        They're superseded by ControlActions.
        
        .. deprecated::
        
            Class is deprecated.
        """
        ADD_ITEM = ListboxControlActions.ADD_ITEM
        """
        Adds an item to the content of the listbox.
        
        The given item has to be a string.
        """
        ADD_ITEMS = ListboxControlActions.ADD_ITEMS
        """
        Adds a sequence of strings to the content of the listbox.
        """
        DELETE_ITEM = ListboxControlActions.DELETE_ITEM
        """
        Removes an item from a listbox.
        
        The given value has to be a position. If the position is invalid an exception will be thrown. The index of the first position is 0. The value should be a sal_Int32.
        """
        DELETE_ITEMS = ListboxControlActions.DELETE_ITEMS
        """
        Removes all items from the listbox.
        """
        SET_SELECT_ITEM = ListboxControlActions.SET_SELECT_ITEM
        """
        Selects an item in a listbox.
        
        The given value has to be a position. The index of the first position is 0. A value of -1 removes the selection. If the given position is invalid an exception will be thrown. The value should be a sal_Int32.
        """
        GET_ITEMS = ListboxControlActions.GET_ITEMS
        """
        Returns all items of the listbox as a sequence of strings.
        """
        GET_SELECTED_ITEM = ListboxControlActions.GET_SELECTED_ITEM
        """
        Returns the currently selected item.
        
        The returned item is an empty string if the listbox is empty or no item is selected.
        """

__all__ = ['ListboxControlActions', 'ListboxControlActionsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class CheckinArgument(object):
    """
    Struct Class

    contains information needed to checkin a document.
    
    The checkin command is always called on the target private working copy document.

    See Also:
        `API CheckinArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1CheckinArgument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.CheckinArgument'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.CheckinArgument'
    """Literal Constant ``com.sun.star.ucb.CheckinArgument``"""

    def __init__(self, MajorVersion: typing.Optional[bool] = False, VersionComment: typing.Optional[str] = '', SourceURL: typing.Optional[str] = '', TargetURL: typing.Optional[str] = '', NewTitle: typing.Optional[str] = '', MimeType: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            MajorVersion (bool, optional): MajorVersion value.
            VersionComment (str, optional): VersionComment value.
            SourceURL (str, optional): SourceURL value.
            TargetURL (str, optional): TargetURL value.
            NewTitle (str, optional): NewTitle value.
            MimeType (str, optional): MimeType value.
        """
        super().__init__()

        if isinstance(MajorVersion, CheckinArgument):
            oth: CheckinArgument = MajorVersion
            self.MajorVersion = oth.MajorVersion
            self.VersionComment = oth.VersionComment
            self.SourceURL = oth.SourceURL
            self.TargetURL = oth.TargetURL
            self.NewTitle = oth.NewTitle
            self.MimeType = oth.MimeType
            return

        kargs = {
            "MajorVersion": MajorVersion,
            "VersionComment": VersionComment,
            "SourceURL": SourceURL,
            "TargetURL": TargetURL,
            "NewTitle": NewTitle,
            "MimeType": MimeType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._major_version = kwargs["MajorVersion"]
        self._version_comment = kwargs["VersionComment"]
        self._source_url = kwargs["SourceURL"]
        self._target_url = kwargs["TargetURL"]
        self._new_title = kwargs["NewTitle"]
        self._mime_type = kwargs["MimeType"]


    @property
    def MajorVersion(self) -> bool:
        """
        Tells whether to create a new major or minor version during the checkin.
        """
        return self._major_version

    @MajorVersion.setter
    def MajorVersion(self, value: bool) -> None:
        self._major_version = value

    @property
    def VersionComment(self) -> str:
        """
        Contains the version comment to set during the checkin.
        """
        return self._version_comment

    @VersionComment.setter
    def VersionComment(self, value: str) -> None:
        self._version_comment = value

    @property
    def SourceURL(self) -> str:
        """
        contains the URL of the source of the action (e.g.
        
        the URL of the temporary file to checkin).
        """
        return self._source_url

    @SourceURL.setter
    def SourceURL(self, value: str) -> None:
        self._source_url = value

    @property
    def TargetURL(self) -> str:
        """
        contains the URL of the private working copy to checkin.
        """
        return self._target_url

    @TargetURL.setter
    def TargetURL(self, value: str) -> None:
        self._target_url = value

    @property
    def NewTitle(self) -> str:
        """
        contains the title of the transferred object, if it is different from the original one.
        
        If this field is filled, for example, a file will be renamed while it is being checked in.
        """
        return self._new_title

    @NewTitle.setter
    def NewTitle(self, value: str) -> None:
        self._new_title = value

    @property
    def MimeType(self) -> str:
        """
        contains the Mime-Type of the content to check-in as it may be different from the original one.
        """
        return self._mime_type

    @MimeType.setter
    def MimeType(self, value: str) -> None:
        self._mime_type = value


__all__ = ['CheckinArgument']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d


class DatabaseParameterEvent(EventObject_a3d70b03):
    """
    Struct Class

    is fired if values for parameters are needed.

    See Also:
        `API DatabaseParameterEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1form_1_1DatabaseParameterEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.DatabaseParameterEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.form.DatabaseParameterEvent'
    """Literal Constant ``com.sun.star.form.DatabaseParameterEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Parameters: typing.Optional[XIndexAccess_f0910d6d] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Parameters (XIndexAccess, optional): Parameters value.
        """

        if isinstance(Source, DatabaseParameterEvent):
            oth: DatabaseParameterEvent = Source
            self.Source = oth.Source
            self.Parameters = oth.Parameters
            return

        kargs = {
            "Source": Source,
            "Parameters": Parameters,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._parameters = kwargs["Parameters"]
        inst_keys = ('Parameters',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Parameters(self) -> XIndexAccess_f0910d6d:
        """
        specifies the list of parameters which are required for opening a result set.
        
        Usually, a com.sun.star.form.component.DataForm fires this event when loading the form requires parameters to be filled in.
        
        Every parameter object supports the com.sun.star.beans.XPropertySet interface, and at least the properties Name and Value
        """
        return self._parameters

    @Parameters.setter
    def Parameters(self, value: XIndexAccess_f0910d6d) -> None:
        self._parameters = value


__all__ = ['DatabaseParameterEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_toolkit3 import XToolkit3 as XToolkit3_84a409c5

class XToolkitExperimental(XToolkit3_84a409c5):
    """
    Work in progress, don't use unless you know what you are doing.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API XToolkitExperimental <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitExperimental.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XToolkitExperimental'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XToolkitExperimental'

    @abstractmethod
    def getOpenGLBufferSwapCounter(self) -> int:
        """
        Get the number of OpenGL buffer swaps.
        """
        ...
    @abstractmethod
    def getRecordingAndClear(self) -> typing.Tuple[str, ...]:
        """
        Query time logs and clear recording.
        
        First line is the time of the recorded operations in seconds, next ones are the log lines. A log line contains the thread ID, time stamp, profile zone ID and \"start\" or \"stop\".
        
        **since**
        
            LibreOffice 6.0
        """
        ...
    @abstractmethod
    def pause(self, nMilliseconds: int) -> None:
        """
        Pause the main thread of LibreOffice for the requested amount of time.
        """
        ...
    @abstractmethod
    def processEventsToIdle(self) -> None:
        """
        Process all pending idle events.
        """
        ...
    @abstractmethod
    def setDeterministicScheduling(self, bDeterministicMode: bool) -> None:
        """
        Turn on or off deterministic scheduling (off is the default).
        """
        ...
    @abstractmethod
    def startRecording(self) -> None:
        """
        Start time logging.
        
        **since**
        
            LibreOffice 6.0
        """
        ...
    @abstractmethod
    def stopRecording(self) -> None:
        """
        Stop time logging.
        
        **since**
        
            LibreOffice 6.0
        """
        ...

__all__ = ['XToolkitExperimental']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class FontUnderline(object):
    """
    Const Class

    These values are used to specify the kind of underlining.
    
    They may be expanded in future versions.

    See Also:
        `API FontUnderline <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontUnderline.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontUnderline'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    specifies no underlining.
    """
    SINGLE = 1
    """
    specifies underlining with a single line.
    """
    DOUBLE = 2
    """
    specifies underlining with a double line.
    """
    DOTTED = 3
    """
    specifies underlining with a dotted line.
    """
    DONTKNOW = 4
    """
    The kind of underlining is not known.
    """
    DASH = 5
    """
    specifies underlining with a dashed line.
    """
    LONGDASH = 6
    """
    specifies underlining with long dashes.
    """
    DASHDOT = 7
    """
    specifies underlining with a dash and dot sequence.
    """
    DASHDOTDOT = 8
    """
    specifies underlining with a dash, dot, dot sequence.
    """
    SMALLWAVE = 9
    """
    specifies underlining with a small wave.
    """
    WAVE = 10
    """
    specifies underlining with a wave.
    """
    DOUBLEWAVE = 11
    """
    specifies underlining with a double wave.
    """
    BOLD = 12
    """
    specifies underlining with a bold line.
    """
    BOLDDOTTED = 13
    """
    specifies underlining with bold dots.
    """
    BOLDDASH = 14
    """
    specifies underlining with bold dashes.
    """
    BOLDLONGDASH = 15
    """
    specifies underlining with long bold dashes.
    """
    BOLDDASHDOT = 16
    """
    specifies underlining with a dash and dot sequence in bold.
    """
    BOLDDASHDOTDOT = 17
    """
    specifies underlining with a dash, dot, dot sequence in bold.
    """
    BOLDWAVE = 18
    """
    specifies underlining with a bold wave.
    """

__all__ = ['FontUnderline']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_layer import XLayer as XLayer_4cd50fcb
if typing.TYPE_CHECKING:
    from .x_layer_handler import XLayerHandler as XLayerHandler_c5d61289

class XCompositeLayer(XLayer_4cd50fcb):
    """
    provides read access to layers that contain sublayers accessible through an additional criterion (for instance the locale they contain data for).
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XCompositeLayer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XCompositeLayer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XCompositeLayer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XCompositeLayer'

    @abstractmethod
    def listSubLayerIds(self) -> typing.Tuple[str, ...]:
        """
        Returns a list of the criteria that can be used to access the sublayers.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def readSubLayerData(self, aHandler: XLayerHandler_c5d61289, aSubLayerId: str) -> None:
        """
        Describes the content of a particular sublayer to an XLayerHandler.
        
        Must be one the identifiers returned by XCompositeLayer.listSubLayerIds()

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            MalformedDataException: ``MalformedDataException``
        """
        ...

__all__ = ['XCompositeLayer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_resource_factory import XResourceFactory as XResourceFactory_b3561268

class XResourceFactoryManager(ABC):
    """
    The XResourceFactoryManager is part of the configuration controller and manages the set of registered resource factories.

    See Also:
        `API XResourceFactoryManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResourceFactoryManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XResourceFactoryManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XResourceFactoryManager'

    @abstractmethod
    def addResourceFactory(self, sResourceURL: str, xResourceFactory: XResourceFactory_b3561268) -> None:
        """
        Register a new resource factory for the given URL.
        
        When one factory is responsible for more than one type of resource then this method has to be called for each type. If this method is called multiple times for the same URL then a previously registered factory is removed for the URL.
        """
        ...
    @abstractmethod
    def getResourceFactory(self, sResourceURL: str) -> XResourceFactory_b3561268:
        """
        Return the resource factory that was previously registered for the given resource type.
        
        This method is typically called by one of the resource controllers.
        """
        ...
    @abstractmethod
    def removeResourceFactoryForReference(self, xResourceFactory: XResourceFactory_b3561268) -> None:
        """
        Remove a resource factory for all resource types it has been registered for.
        
        Use removeResourceFactoryForURL() to remove a factory just for one resource type and to leave it registered for others.
        """
        ...
    @abstractmethod
    def removeResourceFactoryForURL(self, sResourceURL: str) -> None:
        """
        Remove a resource factory for one type of resource.
        
        When the factory has been registered for other URLs as well then it remains registered for them. Use the removeResourceFactoryForReference() to remove a factory completely.
        """
        ...

__all__ = ['XResourceFactoryManager']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.chart2.data.data_filter import DataFilter as DataFilter
with suppress(ImportError):
    from ....dyn.chart2.data.data_provider import DataProvider as DataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.data_sequence import DataSequence as DataSequence
with suppress(ImportError):
    from ....dyn.chart2.data.data_sequence_role import DataSequenceRole as DataSequenceRole
with suppress(ImportError):
    from ....dyn.chart2.data.data_sink import DataSink as DataSink
with suppress(ImportError):
    from ....dyn.chart2.data.data_source import DataSource as DataSource
with suppress(ImportError):
    from ....dyn.chart2.data.database_data_provider import DatabaseDataProvider as DatabaseDataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.highlighted_range import HighlightedRange as HighlightedRange
with suppress(ImportError):
    from ....dyn.chart2.data.label_origin import LabelOrigin as LabelOrigin
with suppress(ImportError):
    from ....dyn.chart2.data.labeled_data_sequence import LabeledDataSequence as LabeledDataSequence
with suppress(ImportError):
    from ....dyn.chart2.data.pivot_table_field_entry import PivotTableFieldEntry as PivotTableFieldEntry
with suppress(ImportError):
    from ....dyn.chart2.data.range_highlight_listener import RangeHighlightListener as RangeHighlightListener
with suppress(ImportError):
    from ....dyn.chart2.data.range_highlighter import RangeHighlighter as RangeHighlighter
with suppress(ImportError):
    from ....dyn.chart2.data.tabular_data_provider_arguments import TabularDataProviderArguments as TabularDataProviderArguments
with suppress(ImportError):
    from ....dyn.chart2.data.x_data_provider import XDataProvider as XDataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.x_data_receiver import XDataReceiver as XDataReceiver
with suppress(ImportError):
    from ....dyn.chart2.data.x_data_sequence import XDataSequence as XDataSequence
with suppress(ImportError):
    from ....dyn.chart2.data.x_data_sink import XDataSink as XDataSink
with suppress(ImportError):
    from ....dyn.chart2.data.x_data_source import XDataSource as XDataSource
with suppress(ImportError):
    from ....dyn.chart2.data.x_database_data_provider import XDatabaseDataProvider as XDatabaseDataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.x_labeled_data_sequence import XLabeledDataSequence as XLabeledDataSequence
with suppress(ImportError):
    from ....dyn.chart2.data.x_labeled_data_sequence2 import XLabeledDataSequence2 as XLabeledDataSequence2
with suppress(ImportError):
    from ....dyn.chart2.data.x_numerical_data_sequence import XNumericalDataSequence as XNumericalDataSequence
with suppress(ImportError):
    from ....dyn.chart2.data.x_pivot_table_data_provider import XPivotTableDataProvider as XPivotTableDataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.x_range_highlighter import XRangeHighlighter as XRangeHighlighter
with suppress(ImportError):
    from ....dyn.chart2.data.x_range_xml_conversion import XRangeXMLConversion as XRangeXMLConversion
with suppress(ImportError):
    from ....dyn.chart2.data.x_sheet_data_provider import XSheetDataProvider as XSheetDataProvider
with suppress(ImportError):
    from ....dyn.chart2.data.x_textual_data_sequence import XTextualDataSequence as XTextualDataSequence



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.packages.manifest
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ...io.x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XManifestWriter(XInterface_8f010a43):
    """
    This interface writes the manifest data to a file.
    
    The user calls writeManifestSequence() with the XOutputStream to write the data to and the sequence of manifest entries to be written passed as parameters. Each manifest entry is represented by a sequence of PropertyValues.

    See Also:
        `API XManifestWriter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1packages_1_1manifest_1_1XManifestWriter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.packages.manifest'
    __ooo_full_ns__: str = 'com.sun.star.packages.manifest.XManifestWriter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.packages.manifest.XManifestWriter'

    @abstractmethod
    def writeManifestSequence(self, rStream: XOutputStream_a4e00b35, rSequence: typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]) -> None:
        """
        Writes the supplied sequence of manifest entries to the supplied XOutputStream.
        """
        ...

__all__ = ['XManifestWriter']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XLibraryAccess(XInterface_8f010a43):
    """
    provides access to additional scripting code.
    
    This code is organized in modules and these modules contain the functions. It is possible to get just the code from a function, but you can also get the whole code of a module with all functions in it.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XLibraryAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XLibraryAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XLibraryAccess'

    @abstractmethod
    def getFunctionCode(self, FunctionName: str) -> uno.ByteSequence:
        """
        Get the compiled code of a function.
        """
        ...
    @abstractmethod
    def getFunctionSource(self, aFunctionName: str) -> str:
        """
        get the source code of a function.
        """
        ...
    @abstractmethod
    def getModuleCode(self, aModuleName: str) -> uno.ByteSequence:
        """
        Get the whole compiled code of a module.
        """
        ...
    @abstractmethod
    def getModuleNames(self) -> typing.Tuple[str, ...]:
        """
        Return all module names which contain code.
        
        e.g., { \"UtilLibrary.ModuleDate\", \"UtilLibrary.Output\", ... }
        """
        ...
    @abstractmethod
    def getModuleSource(self, aModulName: str) -> str:
        """
        get the source code of a module.
        """
        ...
    @abstractmethod
    def isFunction(self, aFunctionName: str) -> bool:
        """
        returns TRUE, if the function is accessible through this library; otherwise it returns FALSE.
        """
        ...
    @abstractmethod
    def isValidPath(self, aPathName: str) -> bool:
        """
        returns TRUE if a fully qualified function name begins with this name.
        """
        ...

__all__ = ['XLibraryAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2.data
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_labeled_data_sequence import XLabeledDataSequence as XLabeledDataSequence_7e1a10c8

class XDataSink(XInterface_8f010a43):
    """
    is a container for sequences of data.
    
    With this interface data can only be written to.
    
    If you want to be able to also read the data set here, your component must also implement XDataSource.

    See Also:
        `API XDataSink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataSink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.XDataSink'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.data.XDataSink'

    @abstractmethod
    def setData(self, aData: typing.Tuple[XLabeledDataSequence_7e1a10c8, ...]) -> None:
        """
        sets new data sequences.
        
        The elements set here must support the service DataSequence.
        
        If the data consist only of floating point numbers (double values), the instances set here should also support the service NumericalDataSequence.
        
        If the data consist only of strings, the instances set here should also support the service TextualDataSequence.
        
        If one of the derived services is supported by one element of the sequence, it should be available for all elements in the sequence.
        """
        ...

__all__ = ['XDataSink']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class KCharacterType(object):
    """
    Const Class

    Constants to identify the character type.
    
    Returned by XCharacterClassification.getCharacterType() and XCharacterClassification.getStringType()

    See Also:
        `API KCharacterType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KCharacterType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.KCharacterType'
    __ooo_type_name__: str = 'const'

    DIGIT = 1
    """
    digit
    """
    UPPER = 2
    """
    upper case alpha letter
    """
    LOWER = 4
    """
    lower case alpha letter
    """
    TITLE_CASE = 8
    """
    title case alpha letter
    """
    ALPHA = 14
    """
    any alpha, ALPHA = UPPER | LOWER | TITLE_CASE
    """
    CONTROL = 16
    """
    control character
    """
    PRINTABLE = 32
    """
    printable character
    """
    BASE_FORM = 64
    """
    base form
    """
    LETTER = 128
    """
    any UnicodeType...._LETTER.
    
    Note that a LETTER must not necessarily be ALPHA
    """

__all__ = ['KCharacterType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class RealRectangle3D(object):
    """
    Struct Class

    This structure contains the necessary information for a three-dimensional cube.
    
    **since**
    
        OOo 2.0

    See Also:
        `API RealRectangle3D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle3D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.geometry'
    __ooo_full_ns__: str = 'com.sun.star.geometry.RealRectangle3D'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.geometry.RealRectangle3D'
    """Literal Constant ``com.sun.star.geometry.RealRectangle3D``"""

    def __init__(self, X1: typing.Optional[float] = 0.0, Y1: typing.Optional[float] = 0.0, Z1: typing.Optional[float] = 0.0, X2: typing.Optional[float] = 0.0, Y2: typing.Optional[float] = 0.0, Z2: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            X1 (float, optional): X1 value.
            Y1 (float, optional): Y1 value.
            Z1 (float, optional): Z1 value.
            X2 (float, optional): X2 value.
            Y2 (float, optional): Y2 value.
            Z2 (float, optional): Z2 value.
        """
        super().__init__()

        if isinstance(X1, RealRectangle3D):
            oth: RealRectangle3D = X1
            self.X1 = oth.X1
            self.Y1 = oth.Y1
            self.Z1 = oth.Z1
            self.X2 = oth.X2
            self.Y2 = oth.Y2
            self.Z2 = oth.Z2
            return

        kargs = {
            "X1": X1,
            "Y1": Y1,
            "Z1": Z1,
            "X2": X2,
            "Y2": Y2,
            "Z2": Z2,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._x1 = kwargs["X1"]
        self._y1 = kwargs["Y1"]
        self._z1 = kwargs["Z1"]
        self._x2 = kwargs["X2"]
        self._y2 = kwargs["Y2"]
        self._z2 = kwargs["Z2"]


    @property
    def X1(self) -> float:
        """
        minimum X coordinate.
        """
        return self._x1

    @X1.setter
    def X1(self, value: float) -> None:
        self._x1 = value

    @property
    def Y1(self) -> float:
        """
        minimum Y coordinate.
        """
        return self._y1

    @Y1.setter
    def Y1(self, value: float) -> None:
        self._y1 = value

    @property
    def Z1(self) -> float:
        """
        minimum Z coordinate.
        """
        return self._z1

    @Z1.setter
    def Z1(self, value: float) -> None:
        self._z1 = value

    @property
    def X2(self) -> float:
        """
        maximum X coordinate.
        
        Must be greater than X1 for non-empty cubes.
        
        .
        """
        return self._x2

    @X2.setter
    def X2(self, value: float) -> None:
        self._x2 = value

    @property
    def Y2(self) -> float:
        """
        maximum Y coordinate.
        
        Must be greater than Y1 for non-empty cubes.
        """
        return self._y2

    @Y2.setter
    def Y2(self, value: float) -> None:
        self._y2 = value

    @property
    def Z2(self) -> float:
        """
        maximum Z coordinate.
        
        Must be greater than Z1 for non-empty cubes.
        """
        return self._z2

    @Z2.setter
    def Z2(self, value: float) -> None:
        self._z2 = value


__all__ = ['RealRectangle3D']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from .fill_properties import FillProperties as FillProperties_f1200da8
from .line_properties import LineProperties as LineProperties_f13f0da9
from .rotation_descriptor import RotationDescriptor as RotationDescriptor_2cec0f63
from .shadow_properties import ShadowProperties as ShadowProperties_e350e87
from .shape import Shape as Shape_85cc09e5
from .text import Text as Text_7c140999
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e

class CaptionShape(FillProperties_f1200da8, LineProperties_f13f0da9, RotationDescriptor_2cec0f63, ShadowProperties_e350e87, Shape_85cc09e5, Text_7c140999):
    """
    Service Class

    The CaptionShape represents a rectangular drawing shape with an additional set of lines.
    
    It can be used as a description for a fixed point inside a drawing.

    See Also:
        `API CaptionShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.CaptionShape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CaptionAngle(self) -> int:
        """
        This property specifies the escape angle of the line of a caption.
        
        It is only used if CaptionIsFixedAngle is set to TRUE
        """
        ...

    @abstractproperty
    def CaptionEscapeAbsolute(self) -> int:
        """
        This property specifies the absolute escape distance for the line of a caption.
        """
        ...

    @abstractproperty
    def CaptionEscapeDirection(self) -> int:
        """
        This property specifies the escape direction for the line of a caption.
        """
        ...

    @abstractproperty
    def CaptionEscapeRelative(self) -> int:
        """
        This property specifies the relative escape distance for the line of a caption.
        """
        ...

    @abstractproperty
    def CaptionGap(self) -> int:
        """
        This property specifies the distance between the text area of the caption and the start of the line.
        """
        ...

    @abstractproperty
    def CaptionIsEscapeRelative(self) -> bool:
        """
        If this property is TRUE, the property CaptionEscapeRelative is used, else the property CaptionEscapeAbsolute is used.
        """
        ...

    @abstractproperty
    def CaptionIsFitLineLength(self) -> bool:
        """
        If this property is TRUE, the application determines the best possible length for the caption line.
        """
        ...

    @abstractproperty
    def CaptionIsFixedAngle(self) -> bool:
        """
        This property specifies if the escape angle of the line of a caption is fixed or free.
        
        If this is set to FALSE, the application can choose the best possible angle. If not, the value in CaptionAngle is used.
        """
        ...

    @abstractproperty
    def CaptionLineLength(self) -> int:
        """
        This property specifies the length of the caption line.
        """
        ...

    @abstractproperty
    def CaptionPoint(self) -> Point_5fb2085e:
        """
        The caption point property specify the position of the point that is captioned.
        
        A set of lines are rendered from the caption area.
        """
        ...

    @abstractproperty
    def CaptionType(self) -> int:
        """
        This property specifies the geometry of the line of a caption.
        """
        ...

    @abstractproperty
    def CornerRadius(self) -> int:
        """
        This is the radius of the caption area corners.
        """
        ...


__all__ = ['CaptionShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.packages
from __future__ import annotations
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_named import XNamed as XNamed_a6520b08
from ..io.x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3

class PackageStream(XPropertySet_bc180bfa, XChild_a6390b07, XNamed_a6520b08, XActiveDataSink_b8d00ba3):
    """
    Service Class

    This service represents a stream contained within a Package.
    
    Instances of this class can only be constructed by the implementation of the Package service.

    See Also:
        `API PackageStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1packages_1_1PackageStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.packages'
    __ooo_full_ns__: str = 'com.sun.star.packages.PackageStream'
    __ooo_type_name__: str = 'service'


__all__ = ['PackageStream']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2.data
from __future__ import annotations
import typing
import uno
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from com.sun.star.chart.ChartDataRowSource import ChartDataRowSourceProto  # type: ignore

class TabularDataProviderArguments(ABC):
    """
    Service Class


    See Also:
        `API TabularDataProviderArguments <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1TabularDataProviderArguments.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.TabularDataProviderArguments'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SequenceMapping(self) -> uno.ByteSequence:
        """
        determines the order of the created labeled sequences
        
        For example a SequenceMapping of [3,0,2,1] indicates that the sequence from old position \"3\" should now be the first one. Then comes the sequence from old position \"0\". Then that one from old position \"2\" and then the sequence from old position \"1\".
        
        If the SequenceMapping contains invalid indexes just ignore those single indexes. For example if you only have three labeled sequences and a SequenceMapping [2,5,1,0], you should ignore the \"5\" and continue to place the sequence from old index \"1\" to the next new position and so on.
        
        If the given SequenceMapping does not cover all existing labeled sequences just put the remaining sequences in old order behind the others. For example you have 4 sequences and a SequenceMapping [3,1]. The result should be as if [3,1,0,2] was given.
        """
        ...

    @abstractproperty
    def CellRangeRepresentation(self) -> str:
        """
        the range address string spanning all data.
        
        The range address string must be interpretable by the component that implements XDataProvider and gets this property as argument to XDataProvider.detectArguments().
        
        The representation string is of a form that may be used in the user interface. Example for OOo Calc: \"$Sheet1.$A$1:$D$7\", example for OOo Writer: \"&lt;Table1.A1:D7&gt;\".
        
        When used as input, this range will be split in columns or rows depending on the property DataRowSource.
        
        When used as output of XDataProvider.detectArguments() this is the range that spans the ranges of all given XDataSequences. If the result is ambiguous, i.e., a splitting of this range would not yield the same result, this property should be empty. The latter is the case, when ranges are overlapping, the lengths of sequences are not equal or even if the order of two sequences is swapped (e.g. data comes from column A, C, B).
        """
        ...

    @abstractproperty
    def DataRowSource(self) -> ChartDataRowSourceProto:
        """
        determines, whether data sequences are created out of columns or rows in a table.
        
        If this property is not given as argument it is assumed to com.sun.star.chart.ChartDataRowSource.COLUMNS, i.e., the default is \"take data from columns\".
        """
        ...

    @abstractproperty
    def FirstCellAsLabel(self) -> bool:
        """
        If data comes from columns, the first row will provide the labels for all sequences, if data comes from rows, the first column will provide the labels for all sequences.
        
        Even if this property is false, the XLabeledDataSequence may contain a label, but this will not be the first cell of the selection. It may be a generic string like \"Column C\".
        
        If this property is not given as argument it is assumed to be FALSE, i.e., the default is \"no labels\".
        """
        ...

    @abstractproperty
    def HasCategories(self) -> bool:
        """
        If FALSE the data provider may create a data sequence containing generated categories that fit the rest of the data, like e.g.
        
        \"Row 12\", \"Row 13\", etc.
        
        This property is not relevant for the splitting up of the data. It just indicates, if the chart wants to use part of the data as categories, so that generic categories can be returned if it doesn't.
        
        The generic category labeled sequence returned should be the first one in the returned XDataSource. It needs no label. The values should have their role set to \"categories\". The generic strings returned should also be localized.
        """
        ...

    @abstractproperty
    def TableNumberList(self) -> str:
        """
        This property is for providing proprietary table indexes for each table appearing in a range given in CellRangeRepresentation.
        
        This argument is supported by Spreadsheets in order to be able to export a document into the StarOffice 5.0 binary format.
        
        Example: If you have the sheets (Sheet1, Sheet2, Sheet3) in your document and a chart uses the range \"Sheet2.A1:.A5 Sheet3.A1:.A5 Sheet2.B1:.B5 Sheet1:B1:.B5\", your TableNumberList would be \"1 2 1 0\". A simple range like \"Sheet1.A1:.E4\" would have the TableNumberList in \"0\"
        
        .
        """
        ...


__all__ = ['TabularDataProviderArguments']